@@ -131,7 +131,6 @@ class DSI():
                                      #          ('sat', 'vio', 'df', or 'best')
             
             # ----- Design Space Parameters ----- #
-            'extra_points': [],  # Extra data points for design space identification
             'dsplabel': 'DSp',   # Label of surface/boundary
             'dspcolor': 'black', # Color of the surface/boundary (both)
             'dspwidth': 4,       # Thickness of the boundary (2D)
@@ -483,19 +482,18 @@ class DSI():
                 flag = True in r
                 vnum = vio[r].shape[0]
                 maxvnum = opt['maxvp']*(self.sat.shape[0] + vnum)
-                if vnum <= maxvnum: # early break based on maxvnum
-                    if print_flag:
-                        print(i + 1, mp, flag)
-                    sol_flag = f'vnum is LE maxvnum ({opt["maxvp"]*100:.1f}%): {vnum} <= {maxvnum}'
-                    break
-                elif flag == True:
+                if vnum <= maxvnum: # tolerance based
+                    flag = False
+                else:
+                    flag = True
+                if flag == True:
                     ub = mp
                 elif flag == False:
                     lb = mp
                     if ub - lb <= tol:
                         if print_flag:
                             print(i + 1, mp, flag)
-                        sol_flag = f'[{i + 1}] Optimal amul found: {mp:6f}   Gap: {ub - lb:6f}'
+                        sol_flag = f'[{i + 1}] Optimal amul found: {mp:6f}   alpha: {a*mp:6f}   Tol: {tol:1.3e}   Gap: {ub - lb:1.3e}'
                         break
                 if print_flag:
                     print(i + 1, mp, flag)
@@ -956,8 +954,8 @@ class DSI():
         
         return fs_R
     
-    def send_output(self, output_filename = 'DSI_output', appendix = True,\
-            rp_pkl = True):
+    def send_output(self, output_filename = 'DSI_output', appendix = False,\
+            rp_pkl = False):
         """
         Send report of the DSI study as a txt file and .pkl file.
         """
